Description: Welcome to the Oregon Judicial Department home page. From here you may access OJIN OnLine and other online services, view the Appellate and circuit courts sites, read news releases and appellate court opinions.
Keywords: OJD, Oregon, Judicial, OJIN OnLine, Appellate, circuit, courts, opinions, cases

Oregon Judicial Department Home | Contact Us | Help | Text Size A+ A- A

Home > Supreme Court

# Supreme Court Opinions

The Supreme Court opinions are published weekly on Thursdays. During weeks in which there is a Monday holiday, the Supreme Court will generally issue its media releases and opinions on Friday.

# Opinions Issued in 2012

January, February, March, April, May, June

# Opinions Issued in Prior Years

2011, 2010, 2009, 2008, 2007, 2006, 2005, 2004, 2003, 2002, 2001, 2000, 1999, 1998

# 2012 Opinions

## ADVANCE SHEETS 2012 # 15
BV: 352 Or

## SUPREME COURT

06/14/12

- S058601 Doe v. Corp. of Presiding Bishop
- S059467 In re Goff

##

## ADVANCE SHEETS 2012 # 14
BV: 352 Or App

## SUPREME COURT

06/07/12

- S060320 State v. Bray
- S058860 State v. Moss

##

## ADVANCE SHEETS 2012 # 13
BV: 352 Or

## SUPREME COURT

05/24/12

- S060295 State v. McDowell

##

## ADVANCE SHEETS 2012 # 12
BV: 352 Or

## SUPREME COURT

05/10/12

- S059602 State v. Eumana-Moranchel

##

## ADVANCE SHEETS 2012 # 11
BV: 351 Or

## SUPREME COURT

04/26/12

- S059326 State v. Miskell/Sinibaldi
- S059521 State v. Jarnagin
- S058445 Eads v. Borman

##

## ADVANCE SHEETS 2012 # 09
BV: 351 Or

## SUPREME COURT

03/29/12

- S053206 State v. Langley

##

## ADVANCE SHEETS 2012 # 08
BV: 351 Or

## SUPREME COURT

03/15/12

- S060086 Green/Harmon v. Kroger
- S059925 State v. Blok (Mandamus Proceeding)
- S060079 State v. MacBale (Mandamus Proceeding)

##

## ADVANCE SHEETS 2012 # 07
BV: 351 Or

## SUPREME COURT

03/01/12

- S059289 State v. Cabanilla

02/24/12

- S059131 Paul v. Providence Health System-Oregon
- S059097 Greenwood Products v. Greenwood Forest Products

##

## ADVANCE SHEETS 2012 # 06
BV: 351 Or

## SUPREME COURT

02/16/12

- S059872 Weber Coastal Bells v. Metro
- S059996 Girod v. Kroger
- S059732 Dept. of Human Services v. J. R. F.
- S059382 Finear and Finear

##

## ADVANCE SHEETS 2012 # 05
BV: 351 Or

## SUPREME COURT

02/02/12

- S059448 Rasmussen v. Kroger
- S059995 Johnson/Girod v. Kroger (S059995)(S059997) (Ballot Title Certified)

##

## ADVANCE SHEETS 2012 # 04
BV: 351 Or

## SUPREME COURT

01/12/12

- S059719 Carson/Thorpe v. Kroger
- S058559 In re Marandas

Search

|  | Search court opinions and briefs for the Supreme Court and the Court of Appeals.

## Other Links

- Supreme Court

- Media Releases

- Appellate Court Records Section

# 2011 Opinions

## ADVANCE SHEETS 2012 # 03
BV: 351 Or

## SUPREME COURT

12/30/11

- S058882 Robinson v. Public Employees Retirement Board
- S059046 Petock v. Asante
- S059213 White v. Public Employees Retirement Board
- S059166 A. G. v. Guitron
- S058846 State v. Rainoldi

## ADVANCE SHEETS 2012 # 01
BV: 351 Or

## SUPREME COURT

12/08/11

- S059713 Girod v. Kroger

## SUPREME COURT

12/02/11

- S059014 Williams v. RJ Reynolds Tobacco Company

## ADVANCE SHEETS 2011 # 26
BV: 351 Or

## SUPREME COURT

11/23/11

- S059448 Rasmussen v. Kroger

## SUPREME COURT

11/21/11

- S059519 State v. Haugen

## SUPREME COURT

11/18/11

- S059138 Montez v. Czerniak

## ADVANCE SHEETS 2011 # 25
BV: 351 Or

## SUPREME COURT

11/10/11

- S057155 ZRZ Realty v. Beneficial Fire and Casualty Ins.
- S059154 Kaseberg v. Davis Wright Tremaine, LLP
- S059135 State v. Swanson
- S059136 State v. Glushko/Little
- S059691 Satrum v. Kroger (S059691) (Ballot Title Certified)
- S059201 Willemsen v. Invacare Corporation (S059201) (Certified Question)

## ADVANCE SHEETS 2011 # 24
BV: 351 Or

## SUPREME COURT

10/20/11

- S058915 Friends of Yamhill County v. Board of Commissioners

## ADVANCE SHEETS 2011 # 23
BV: 351 Or

## SUPREME COURT

10/06/11

- S058881 Arken v. City of Portland
- S059056 Goodson v. PERS
- S058898 State v. Kurokawa-Lasciak
- S059368 Rasmussen v. Kroger
- S059058 Balboa Apartments v. Patrick
- S059447 Lavey v. Kroger (S059447) (Ballot Title Certified)

## ADVANCE SHEETS 2011 # 22
BV: 351 Or

## SUPREME COURT

09/22/11

- S058762 Lasley v. Combined Transport, Inc.
- S058641 State v. Davis
- S059039 State v. Cloutier
- S059555 In re Steffen

## ADVANCE SHEETS 2011 # 21
BV: 350 Or

## SUPREME COURT

09/09/11

- S059065 State v. Ryan
- S058706 Farmers Ins. Co. v. Mowry

## ADVANCE SHEETS 2011 # 20
BV: 350 Or

## SUPREME COURT

09/01/11

- S058311 State ex rel Engweiler v. Felton
- S058967 State v. Baker
- S058839 Drollinger v. Mallon

## SUPREME COURT

08/25/11

- S059045 State v. Lopez-Minjarez

## ADVANCE SHEETS 2011 # 19
BV: 350 Or

## SUPREME COURT

08/12/11

- S059360 Rasmussen v. Kroger (S059360) (Ballot Title Certified)

## ADVANCE SHEETS 2011 # 18
BV: 350 Or

## SUPREME COURT

08/05/11

- S059519 State v. Haugen (Mandamus Proceeding)

## SUPREME COURT

07/28/11

- S059360 Rasmussen v. Kroger
- S058548 State v. Walker
- S059447 Lavey v. Kroger
- S059437 Lindell v. Kalugin (Mandamus Proceeding)

## ADVANCE SHEETS 2011 # 16
BV: 350 Or

## SUPREME COURT

07/08/11

- S058406 State v. Cazares-Mendez/Reyes-Sanchez
- S058572 Strawn v. Farmers Ins. Co.

## SUPREME COURT

06/30/11

- S058310 State v. Speedis
- S058572 State v. Davis
- S058778 In re Lawrence

## SUPREME COURT

06/29/11

- S059519 State v. Haugen (Alternative Writ)

## ADVANCE SHEETS 2011 # 14
BV: 350 Or

## SUPREME COURT

06/03/11

- S058536 Stuart v. Pittman

## ADVANCE SHEETS 2011 # 13
BV: 350 Or

## SUPREME COURT

05/27/11

- S059423 State v. Barrett

## SUPREME COURT

05/26/11

- S058602 State v. Gilmore

## SUPREME COURT

05/23/11

- S059261 Rasmussen v. Kroger (S059261) (Ballot Title Certified)
- S059264 Rasmussen v. Kroger (S059264) (Ballot Title Certified)

## SUPREME COURT

05/19/11

- S058645 Willis v. Winters
- S058725 Morehouse v. Haynes
- S057520 Strawn v. Farmers Ins. Co.

## ADVANCE SHEETS 2011 # 12
BV: 350 Or

## SUPREME COURT

05/05/11

- S057378 State v. Guggenmos
- S059264 Rasmussen v. Kroger (S059264)
- S059261 Rasmussen v. Kroger (S059261)
- S059032 In re Castanza

## ADVANCE SHEETS 2011 # 11
BV: 350 Or

## SUPREME COURT

04/21/11

- S058345 State v. Barger
- S059049 In re Richardson
- S059262 Rasmussen v. Kroger (Ballot Title Certified)

## ADVANCE SHEETS 2011 # 10
BV: 350 Or

## SUPREME COURT

04/14/11

- S058549 State v. Marshall

## SUPREME COURT

04/07/11

- S058769 State v. Fowler
- S058520 Snyder v. Espino-Brown
- S058001 State v. Helzer
- S058240 State v. Foster
- S058252 Force v. Dept. of Rev.
- S058869 In re Lopez
- S058434 In re Oh

## SUPREME COURT

04/06/11

- S058894 Oregonians for Honest Elections v. Oregon Education Association (Mandamus Proceeding)

## ADVANCE SHEETS 2011 # 09
BV: 350 Or

## SUPREME COURT

03/29/11

- S059286 Oregon Pipeline Company, LLC v. Clatsop County (Peremptory Writ)

## SUPREME COURT

03/25/11

- S058346 State v. Kurtz
- S058450 Menasha Forest Products Corp. v. Curry County Title
- S054854 State v. Brumwell
- S057898 In re Groom

## ADVANCE SHEETS 2011 # 08
BV: 350 Or

## SUPREME COURT

03/10/11

- S058620 State v. Garrett
- S058335 State v. Heisser
- S058073 Abraham v. T. Henry Construction, Inc.
- S057751 State v. Stokes

## ADVANCE SHEETS 2011 # 07
BV: 349 Or

## SUPREME COURT

03/04/11

- S059248 State v. American Tobacco Company, Inc. (Certified Appeal Accepted)

## SUPREME COURT

03/03/11

- S057155 ZRZ Realty v. Beneficial Fire and Casualty Ins.

## ADVANCE SHEETS 2011 # 06
BV: 349 Or

## SUPREME COURT

02/18/11

- S059213 White et al v. Public Employees Retirement Board and State of Oregon et al (Certified Appeal Accepted)

## SUPREME COURT

02/17/11

- S057794 State v. Sierra
- S058116 State v. Sundberg
- S058369 State v. Kellar
- S058156 Malan v. Tipton
- S059120 Howell v. Boyle (Certified Question Accepted)
- S058894 Oregonians for Honest Elections v. Oregon Education Association (Alternative Writ)

## ADVANCE SHEETS 2011 # 03
BV: 349 Or

## SUPREME COURT

01/06/11

- S056700 Hamlin v. Hampton Lumber Mills, Inc.
- S058345 State v. Barger
- S057701 State v. Ritchie

# 2010 Opinions

## SUPREME COURT

12/30/10

- S056715 Cler v. Providence Health System-Oregon
- S057794 State v. Sierra
- S053644 Estate of Michelle Schwarz v. Philip Morris Inc.

## SUPREME COURT

12/28/10

- S059056 Goodson v. Public Employees Retirement System (Certified Appeal Accepted)

## ADVANCE SHEETS 2010 # 02
BV: 349 Or

## SUPREME COURT

12/23/10

- S057120 Janowski/Fleming v. Board of Parole
- S057031 Severy/Wilson v. Board of Parole

## SUPREME COURT

12/16/10

- S057820 State v. Moore/Coen
- S057887 Harris and Harris
- S058190 State v. Salas-Juarez
- S059014 Williams v. RJ Reynolds Tobacco Company (Certified Appeal Accepted)

## ADVANCE SHEETS 2010 # 01
BV: 349 Or

## SUPREME COURT

12/09/10

- S057189 State v. Ashbaugh
- S057858 Clackamas Cty Assessor v. Village at Main St. Phase II
- S058081 Hopkins v. SAIF
- S058743 In re Murphy

## SUPREME COURT

12/02/10

- S058307 Polacek and Polacek
- S058330 Bolte and Bolte

## ADVANCE SHEETS 2010 # 26
BV: 349 Or

## SUPREME COURT

11/18/10

- S058025 Siporen v. City of Medford
- S058035 Kelly v. Hochberg

## ADVANCE SHEETS 2010 # 25
BV: 349 Or

## SUPREME COURT

11/12/10

- S057373 Tupper v. Roan
- S057752 Patton v. Target Corp.

## SUPREME COURT

11/05/10

- S058700 Weaver v. Belleque

## SUPREME COURT

11/04/10

- S054853 State v. Haugen

## ADVANCE SHEETS 2010 # 23
BV: 349 Or

## SUPREME COURT

10/25/10

- S058881 Arken v. City of Portland (Certified Appeal Accepted)
- S058882 Robinson v. Public Employees Retirement Board (Certified Appeal Accepted)

## SUPREME COURT

10/14/10

- S057155 ZRZ Realty v. Beneficial Fire and Casualty Ins.
- S057422 Bonds v. Farmers Ins. Co.

## SUPREME COURT

10/12/10

- S058709 Kloor v. West One Automotive Group, Inc. (Alternative Writ)

## ADVANCE SHEETS 2010 # 22
BV: 349 Or

## SUPREME COURT

09/23/10

- S056322 West Linn Corporate Park v. City of West Linn
- S058271 In re Hartfield

## ADVANCE SHEETS 2010 # 21
BV: 349 Or

## SUPREME COURT

09/16/10

- S057895 Dewsnup v. Farmers Ins. Co.
- S058555 State v. Schwab

## SUPREME COURT

09/10/10

- S057581 State v. Partain

## ADVANCE SHEETS 2010 # 20
BV: 349 Or

## SUPREME COURT

08/26/10

- S057691 Colby v. Gunson

## ADVANCE SHEETS 2010 # 19
BV: 348 Or

## SUPREME COURT

08/19/10

- S057958 State v. Baker-Krofft

## SUPREME COURT

08/18/10

- S058709 Kloor v. West One Automotive Group, Inc. (Alternative Writ)

## SUPREME COURT

08/12/10

- S056577 State v. Ayles

## SUPREME COURT

08/10/10

- S058648 Alejandre-Mercado v. Burger (Habeas Corpus Proceeding)

## SUPREME COURT

08/09/10

- S058601 Doe v. Corp. of Presiding Bishop (Alternative Writ)

## ADVANCE SHEETS 2010 # 18
BV: 348 Or

## SUPREME COURT

08/05/10

- S056569 McDowell v. Employment Dept.

## SUPREME COURT

07/29/10

- S058179 State v. Portis
- S057879 State v. Willis
- S056471 In re Hostetter

## ADVANCE SHEETS 2010 # 17
BV: 348 Or

## SUPREME COURT

07/15/10

- S058285 J. G. v. N. D. G.
- S056148 In re Smith

## ADVANCE SHEETS 2010 # 16
BV: 348 Or

## SUPREME COURT

07/09/10

- S057511 Coffey v. Board of Geologist Examiners
- S057832 State v. Daniels

## SUPREME COURT

07/01/10

- S056371 State v. Vondehn

## ADVANCE SHEETS 2010 # 15
BV: 348 Or

## SUPREME COURT

06/24/10

- S053644 Estate of Michelle Schwarz v. Philip Morris Inc.

## SUPREME COURT

06/17/10

- S057387 State ex rel English v. Multnomah County

## ADVANCE SHEETS 2010 # 14
BV: 348 Or

## SUPREME COURT

06/11/10

- S058432 Caruthers v. Kroger (Ballot Title Certified)
- S058433 Caruthers v. Kroger (Ballot Title Certified)
- S058370 Tauman v. Kroger (Ballot Title Certified)

## SUPREME COURT

06/10/10

- S057583 State v. Hamilton
- S057403 State ex rel Juv. Dept. v. M. A. D.
- S057231 In re Newell

## SUPREME COURT

06/04/10

- S056477 State v. Lupoli

## ADVANCE SHEETS 2010 # 13
BV: 348 Or

## SUPREME COURT

05/27/10

- S057594 State v. Brown
- S056998 In re Snyder
- S056480 In re Peterson

## ADVANCE SHEETS 2010 # 12
BV: 348 Or

## SUPREME COURT

05/14/10

- S058313 Whitsett v. Kroger (Ballot Title Certified)

## SUPREME COURT

05/13/10

- S057279 State v. Morgan

## ADVANCE SHEETS 2010 # 11
BV: 348 Or

## SUPREME COURT

04/29/10

- S056990 State v. Moyer
- S058313 Whitsett v. Kroger
- S056494 Snider v. Production Chemical Manufacturing, Inc.
- S057678 Caruthers v. Kroger
- S058332 Caruthers v. Kroger (Ballot Title Certified)

## ADVANCE SHEETS 2010 # 10
BV: 348 Or

## SUPREME COURT

04/16/10

- S058168 Caruthers v. Kroger (Ballot Title Certified)

## SUPREME COURT

04/15/10

- S056265 Emerald Steel Fabricators, Inc. v. BOLI
- S057652 State v. Schoen

## SUPREME COURT

04/08/10

- S057570 Vannatta v. Oregon Government Ethics Comm.
- S056861 Blacknall v. Board of Parole
- S057150 State v. Lennon

## ADVANCE SHEETS 2010 # 09
BV: 348 Or

## SUPREME COURT

04/01/10

- S057014 State v. Hogevoll

## SUPREME COURT

03/25/10

- S057796 State v. Blair
- S056821 State v. Rader
- S057117 State v. Blake
- S058242 Benoit v. Kroger (Ballot Title Certified)
- S058243 Benoit v. Kroger (Ballot Title Certified)
- S058211 Caruthers v. Kroger (Ballot Title Certified)
- S058219 Caruthers v. Kroger (Ballot Title Certified)
- S058220 Caruthers v. Kroger (Ballot Title Certified)
- S058262 Caruthers v. Kroger (Ballot Title Certified)
- S058169 Rogers v. Kroger (Ballot Title Certified)

## ADVANCE SHEETS 2010 # 08
BV: 348 Or

## SUPREME COURT

03/18/10

- S057678 Caruthers v. Kroger

## SUPREME COURT

03/11/10

- S056275 Klamath Irrigation District v. United States

## ADVANCE SHEETS 2010 # 07
BV: 348 Or

## SUPREME COURT

03/04/10

- S056560 State v. Mejia

## ADVANCE SHEETS 2010 # 06
BV: 347 Or

## SUPREME COURT

02/19/10

- S057190 Liberty Northwest Ins. Corp., Inc. v. Watkins
- S057493 Charles v. Palomo
- S057609 McCollum v. Kmart Corporation

## SUPREME COURT

02/18/10

- S057885 Berman v. Kroger (Ballot Title Certified)

## SUPREME COURT

02/16/10

- S058221 State v. Lobo (Mandamus Proceeding)

## SUPREME COURT

02/11/10

- S056239 State v. Rodgers/Kirkeby
- S057910 State v. Machuca
- S057678 Caruthers v. Kroger
- S056842 Datt v. Hill

## ADVANCE SHEETS 2010 # 05
BV: 347 Or

## SUPREME COURT

02/04/10

- S057330 Doyle v. City of Medford
- S057885 Berman v. Kroger
- S056672 Weems/Roberts v. Board of Parole
- S057817 Berman v. Kroger (Ballot Title Certified)

## SUPREME COURT

01/28/10

- S056384 Northwest Natural Gas Co. v. Dept. of Rev.

## ADVANCE SHEETS 2010 # 04
BV: 347 Or

## SUPREME COURT

01/22/10

- S055610 In re Paulson

01/21/10

- S057946 Caruthers v. Kroger (Ballot Title Certified)

01/20/10

- S057817 Berman v. Kroger (Ballot Title Certified)

01/19/10

- S057816 Brady / Berman v. Kroger (Ballot Title Certified)

Back to Top